/**
 * Can be used to mock Recurly.js functionality during automated testing.
 */
export declare class RecurlyJsMock {
    /**
     * Spins up a headless browser instance, creates a Recurly.js compliant form,
     * inputs the desired data and returns the Recurly.js token.
     *
     * @param publicApiKey The public API key of the Recurly account to be used
     * @param logLevel The desired log level. Can be debug, info, warn or error.
     * @param details The payment information to be used to fill out the form
     */
    static getTokenSingleRun(publicApiKey: string, logLevel?: LogLevel, details?: PaymentDetails): Promise<RecurlyToken>;
    /**
     * Returns the Recurly.js token without running a headless browser.
     *
     * @param publicApiKey The public API key of the Recurly account to be used
     * @param logLevel The desired log level. Can be debug, info, warn or error.
     * @param details The payment information to be used
     */
    static getTokenAPICall(publicApiKey: string, logLevel?: LogLevel, details?: PaymentDetails): Promise<RecurlyToken>;
    private static getLogLevelConfiguration(logLevel);
    private static mergeWithDefaults(details);
    /**
     * Deletes undefined values from given details recursively including nested objects.
     */
    private static deleteUndefinedProperties(obj);
    startDaemon(publicApiKey: string, logLevel?: LogLevel): Promise<boolean>;
    stopDaemon(): Promise<boolean>;
    getToken(details: PaymentDetails): Promise<boolean>;
}
export interface RecurlyToken {
    id: string;
}
export declare enum LogLevel {
    Debug = 0,
    Info = 1,
    Warn = 2,
    Error = 3,
}
/**
 * Payment data handled by Recurly.js.
 *
 * @see https://dev.recurly.com/docs/getting-started-1#section-card-data
 * @see https://dev.recurly.com/docs/getting-started-1#section-billing-address
 */
export interface PaymentDetails {
    address1?: string;
    address2?: string;
    cardData?: {
        cvv?: number;
        firstName?: string;
        lastName?: string;
        month?: number;
        number?: string;
        year?: number;
    };
    city?: string;
    country?: string;
    phone?: string;
    postalCode?: string;
    state?: string;
    vatNumber?: string;
}
